Crate tophat

tophat

A small, pragmatic, and flexible async HTTP server library.

More docs coming soon! For now, please see the examples directory for features.

Also, please note that you’ll need to set up your own async runtime to work with tophat. All the examples use smol as the runtime.

Re-exports

Modules

Macros

Structs

  • A streaming body for use with requests and responses.

Type Aliases

  • Currently, Request is not generic over Body type
  • Currently, Response is not generic over Body type